@@ -50,8 +50,9 @@ ANOVA_compromise <- function(design_result,
                              emm_comp,
                              costT1T2 = 1, 
                              priorH1H0 = 1, 
-                             error = "minimal",
+                             error = c("minimal","balance"),
                              liberal_lambda = Superpower_options("liberal_lambda")){
+  error = match.arg(error)
  
 
     if (missing(emm_comp)) {
